==> rktSNS_1.070620.tgz: rktSNS/webapp/libs/private/msg_pictures.php <==
<?php
/* ========================================================================
 - [webapp/libs/private/msg_pictures.php]
 -      メッセージ関連の添付画像クラス
 -      Copyright (c) 2006 Yujiro Takahashi
 - ライセンス:
 -      This program is free software; you can redistribute it and/or
 -      modify it under the terms of the GNU General Public License
 -      as published by the Free Software Foundation; either version 2
 -      of the License, or (at your option) any later version.
 -
 -      This program is distributed in the hope that it will be useful,
 -      but WITHOUT ANY WARRANTY; without even the implied warranty of
 -      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 -      GNU General Public License for more details.
 -
 -      You should have received a copy of the GNU General Public License
 -      along with this program; if not, write to the Free Software
 -      Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 - 問い合わせ先：
 -      yujiro@rakuto.net
 -      http://rakuto.net/rktSNS/
 - 更新履歴：
 -      [2006/07/25] 作成
 - ======================================================================== */

require_once LIB_DIR.'rkt_db.php';
require_once LIB_DIR.'rkt_upload.php';

/**
 * メッセージ関連の添付画像クラス
 *
 * @author 高橋 裕志郎 <yujiro@stepone.tv>
 * @package msg_pictures
 * @access public
 * @version 1.0
 */
class msg_pictures
{
    /**
     * 添付ファイル画像ID
     * @var integer
     */
    var $ids = 0;

    /**
     * ID
     * @var integer
     */
    var $ref_message = 0;

    /**
     * アカウントID
     * @var integer
     */
    var $ref_account = 0;

    /**
     * DB接続オジェクト
     * @var object
     */
    var $objdb = null;

    /**
     * BLOB操作オブジェクト
     * @var object
     */
    var $objfile = null;

    /**
     * コンストラクタ
     *
     * @access public
     * @param integer $ref_message
     * @return void
     */
    function msg_pictures($ref_message)
    {
        $this->objdb = RKT_db::getInstance();
        $this->objfile = RKT_upload::getInstance(BLOB_DRIVER,BLOB_PARAM);

        $this->ref_message = empty($ref_message)?0:$ref_message;

        $objact = account::getInstance();
        $this->ref_account = $objact->getInfo('id');
        $this->set_ids();

        /* 削除画像IDの引継ぎ */
        if (!empty($_POST['picture_delete'])){
            $deletes = array();
            foreach ($_POST['picture_delete'] as $id) {
                if (is_numeric($id)){
                    $deletes[$id] = $id;
                }
            }
            $_SESSION['picture_delete'] = $deletes;
        } // if (!empty($_POST['picture_delete']))
    }

    /**
     * 添付ファイルIDの取得
     *
     * @access private
     * @return void
     */
    function set_ids()
    {
        if (isSet($_SESSION['ref_pictures'])){
            $this->ids = $_SESSION['ref_pictures'];
            return ;
        } // if (isSet($_SESSION['ref_pictures']))
        
        $sql=
            'SELECT '.
                'id '.
            'FROM '.
                DB_PREFIX.'fri_picture '.
            'WHERE '.
                'ref_account = '.$this->ref_account.' AND '.
                'ref_message = '.$this->ref_message;
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);

        $this->ids = array();
        if (empty($result)){
            return ;
        }
        foreach ($result as $value){
            $this->ids[$value['id']] = $value['id'];
        }
    }

    /**
     * 画像のアップロード処理
     *
     * @access public
     * @return integer  データ操作結果
     */
    function doUpload()
    {
        if (empty($_POST['ref_pictures'])){
            return ;
        }

        $this->ids = array();
        $row = 0;
        foreach ($_POST['ref_pictures'] as $id) {
            if (!empty($id)){
                $this->ids[$id] = is_numeric($id)?$id:0;
            }
            $this->upload($id, 'photo'.$row);
            $row++;
        }
        $_SESSION['ref_pictures'] = $this->ids;
    }

    /**
     * 画像のアップロード処理
     *
     * @access public
     * @return integer  データ操作結果
     */
    function upload($id, $name)
    {
        /* 一覧用画像 */
        if (!$this->objfile->catchFile($name)) {
            return false;
        }
        if (!$this->objfile->isImage()){
            return false;
        }

        // ファイルの保存
        $dir = ARCHIVES_UPLOAD_PATH;
        $filename = $this->objfile->getName();
        $extension = $this->objfile->getExtension();

        $temp = md5($this->ref_account.time());
        $name = substr($temp, rand(0,25), 6);

        $large_path = $dir.'large/'.$name.'.'.$extension;
        $small_path = $dir.'small/'.$name.'.'.$extension;

        $large = $this->objfile->saveResize($large_path,PHOTO_MAX_SIZE,PHOTO_MAX_SIZE);
        $small = $this->objfile->saveResize($small_path,PHOTO_SMALL_SIZE,PHOTO_SMALL_SIZE);

        $values = array(
            'modify'=>      $this->objdb->quote(date('Y-m-d H:i:s')),
            'ref_account'=> $this->objdb->quote($this->ref_account),
            'title'=>       $this->objdb->quote($filename),
            'filename'=>    $this->objdb->quote($large_path),
            'width'=>       $this->objdb->quote($large['width']),
            'height'=>      $this->objdb->quote($large['height']),
            'thumbnail'=>   $this->objdb->quote($small_path),
            't_width'=>     $this->objdb->quote($small['width']),
            't_height'=>    $this->objdb->quote($small['height']),
        );

        if (empty($id)){
            $this->insert($values);
        } else {
            $this->update($id,$values);
        }
        return true;
    }

    /**
     * 添付画像を新規登録
     *
     * @access private
     * @param array $values
     * @return boolean  真偽値
     */
    function insert($values)
    {
        $keys   = array_keys($values);
        $column = implode(',', $keys);
        $values = implode(',', $values);

        $sql =
            'INSERT INTO '.
                DB_PREFIX.'fri_picture('.
                    $column.
                ') VALUES ('.
                    $values.
                ')';
        $result = $this->objdb->exec($sql);
        if ($result){
            $id = $this->objdb->lastInsertId();
            $this->ids[$id] = $id;
        }
        return $result;
    }

    /**
     * 添付画像を更新
     *
     * @access private
     * @param integer $id
     * @param array $values
     * @return boolean  真偽値
     */
    function update($id,$values)
    {
        $sql=
            'SELECT '.
                'filename,'.
                'thumbnail '.
            'FROM '.
                DB_PREFIX.'fri_picture '.
            'WHERE '.
                'id = '.$id;
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetch(PDO_FETCH_ASSOC);
        $stmt->closeCursor();

        if (!empty($result)){
            $this->objfile->unlink($result['filename']);
            $this->objfile->unlink($result['thumbnail']);
        }

        foreach ($values as $key=>$value) {
            $value = ($value==='')?'NULL':$value;
            $set = $key.'='.$value.',';
        }

        $sql =
            'UPDATE '.
                DB_PREFIX.'fri_picture '.
            'SET '.
                substr($set, 0, -1).
            ' WHERE '.
                'id = '.$id;
        $result = $this->objdb->exec($sql);
        if ($result){
            $this->ids[$id] = $id;
        }
        return $result;
    }

    /**
     * 画像の削除
     *
     * @access public
     * @param boolean $cahtch
     * @return integer  データ操作結果
     */
    function doDelete($catch=false)
    {
        if ($catch) {
            if (empty($_SESSION['picture_delete'])){
                return ;
            }
            $deletes = $_SESSION['picture_delete'];
            unset($_SESSION['picture_delete']);
        } // if ($catch)
        
        foreach ($deletes as $id){
            $this->delete($id);
        }
    }

    /**
     * 画像の削除
     *
     * @access public
     * @param integer $id
     * @return integer  データ操作結果
     */
    function delete($id)
    {
        $sql=
            'SELECT '.
                'filename,'.
                'thumbnail '.
            'FROM '.
                DB_PREFIX.'fri_picture '.
            'WHERE '.
                'id = '.$id;
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetch(PDO_FETCH_ASSOC);
        $stmt->closeCursor();

        if (empty($result)){
            return 0;
        }

        $this->objfile->unlink($result['filename']);
        $this->objfile->unlink($result['thumbnail']);

        $sql =
            'DELETE FROM '.
                DB_PREFIX.'fri_picture '.
            'WHERE '.
                'id = '.$id;
        return $this->objdb->exec($sql);
    }

    /**
     * 修正等を更新する
     *
     * @access public
     * @param integer $ref_message
     * @return boolean  真偽値
     */
    function setFix($ref_message)
    {
        foreach ($this->ids as $id){
            $this->fix($id,$ref_message);
        }
    }

    /**
     * 修正等を更新する
     *
     * @access public
     * @param integer $ref_message
     * @return boolean  真偽値
     */
    function fix($id,$ref_message)
    {
        $sql=
            'SELECT '.
                'filename,'.
                'thumbnail '.
            'FROM '.
                DB_PREFIX.'fri_picture '.
            'WHERE '.
                'id = '.$id;
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetch(PDO_FETCH_ASSOC);
        $stmt->closeCursor();

        if (empty($result)){
            return 0;
        }
        
        // ファイルの保存
        $dir = ARCHIVES_MEMBER_PATH.$this->ref_account.'/';

        $large_path = ereg_replace(ARCHIVES_UPLOAD_PATH, $dir, $result['filename']);
        $small_path = ereg_replace(ARCHIVES_UPLOAD_PATH, $dir, $result['thumbnail']);

        $this->objfile->setUID($this->ref_account);
        $this->objfile->rename($result['filename'], $large_path);
        $this->objfile->rename($result['thumbnail'], $small_path);
        
        $this->ref_message = $ref_message;
        $sql =
            'UPDATE '.
                DB_PREFIX.'fri_picture '.
            'SET '.
                "modify='".date('Y-m-d H:i:s')."',".
                'ref_message='.$this->ref_message.','.
                "filename='".$large_path."',".
                "thumbnail='".$small_path."' ".
            'WHERE '.
                'id = '.$id;
        return $this->objdb->exec($sql);
    }

    /**
     * 画像をコピーする
     *
     * @access public
     * @param integer $ref_message
     * @param integer $ref_to
     * @return boolean  真偽値
     */
    function setCopy($ref_message,$ref_to)
    {
        if (empty($ref_message)){
            return ;
        }
        foreach ($this->ids as $id){
            $this->copy($id,$ref_message,$ref_to);
        }
    }

    /**
     * 修正等を更新する
     *
     * @access public
     * @param integer $ref_message
     * @return boolean  真偽値
     */
    function copy($id,$ref_message,$ref_to)
    {
        $sql=
            'SELECT '.
                '* '.
            'FROM '.
                DB_PREFIX.'fri_picture '.
            'WHERE '.
                'id = '.$id;
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetch(PDO_FETCH_ASSOC);
        $stmt->closeCursor();

        if (empty($result)){
            return 0;
        }

        // ファイルの保存
        $dir = ARCHIVES_MEMBER_PATH.$ref_to.'/';

        $this->objfile->load($result['filename']);
        $basename = $this->objfile->getName();

        $large_path = $dir.'large/'.$basename;
        $small_path = $dir.'small/'.$basename;

        $this->objfile->setUID($ref_to);
        $this->objfile->save($large_path);

        $this->objfile->load($result['thumbnail']);        
        $this->objfile->setUID($ref_to);
        $this->objfile->save($small_path);

        $values = array(
            'modify'=>      $this->objdb->quote(date('Y-m-d H:i:s')),
            'ref_account'=> $this->objdb->quote($ref_to),
            'ref_message'=> $this->objdb->quote($ref_message),
            'title'=>       $this->objdb->quote($result['title']),
            'filename'=>    $this->objdb->quote($large_path),
            'width'=>       $this->objdb->quote($result['width']),
            'height'=>      $this->objdb->quote($result['height']),
            'thumbnail'=>   $this->objdb->quote($small_path),
            't_width'=>     $this->objdb->quote($result['t_width']),
            't_height'=>    $this->objdb->quote($result['t_height']),
        );
        return $this->insert($values);
    }

    /**
     * 添付画像IDを削除
     *
     * @access public
     * @return void
     */
    function unSetPicture()
    {
        unset($_SESSION['ref_pictures']);
    }

    /**
     * 添付画像情報の取得
     *
     * @access public
     * @return array
     */
    function getImgInfos()
    {
        $ids = implode(',',$this->ids);

        $sql=
            'SELECT '.
                'id,'.
                'thumbnail as src,'.
                't_width as width,'.
                't_height as height '.
            'FROM '.
                DB_PREFIX.'fri_picture '.
            'WHERE '.
                'id in('.$ids.')';
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);

        $list = array();
        $row=0;
        foreach ($result as $value){
            $list[] = $value;
            $row++;
        }
        
        for ($row;$row<3;$row++) {
            $list[] = array(
                'id'=>       null,
                'src'=> NOPHOTO_SMALL,
                'width'=>  PHOTO_SMALL_SIZE,
                'height'=> PHOTO_SMALL_SIZE
            );
        }

        return $list;
    }
}
// msg_pictureの終了
?>

==> rktSNS_1.070830.tgz: rktSNS/webapp/libs/private/msg_pictures.php <==
<?php
/* ========================================================================
 - [webapp/libs/private/msg_pictures.php]
 -      メッセージ関連の添付画像クラス
 -      Copyright (c) 2006 Yujiro Takahashi
 - ライセンス:
 -      This program is free software; you can redistribute it and/or
 -      modify it under the terms of the GNU General Public License
 -      as published by the Free Software Foundation; either version 2
 -      of the License, or (at your option) any later version.
 -
 -      This program is distributed in the hope that it will be useful,
 -      but WITHOUT ANY WARRANTY; without even the implied warranty of
 -      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 -      GNU General Public License for more details.
 -
 -      You should have received a copy of the GNU General Public License
 -      along with this program; if not, write to the Free Software
 -      Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 - 問い合わせ先：
 -      yujiro@rakuto.net
 -      http://rakuto.net/rktSNS/
 - 更新履歴：
 -      [2007/08/30] 画像の更新処理にrkt_manipクラスを使用
 -      [2006/07/25] 作成
 - ======================================================================== */

require_once LIB_DIR.'rkt_db.php';
require_once LIB_DIR.'rkt_manip.php';
require_once LIB_DIR.'rkt_upload.php';

/**
 * メッセージ関連の添付画像クラス
 *
 * @author 高橋 裕志郎 <yujiro@stepone.tv>
 * @package msg_pictures
 * @access public
 * @version 1.0
 */
class msg_pictures
{
    /**
     * 添付ファイル画像ID
     * @var integer
     */
    var $ids = 0;

    /**
     * ID
     * @var integer
     */
    var $ref_message = 0;

    /**
     * アカウントID
     * @var integer
     */
    var $ref_account = 0;

    /**
     * DB接続オジェクト
     * @var object
     */
    var $objdb = null;

    /**
     * BLOB操作オブジェクト
     * @var object
     */
    var $objfile = null;

    /**
     * コンストラクタ
     *
     * @access public
     * @param integer $ref_message
     * @return void
     */
    function msg_pictures($ref_message)
    {
        $this->objdb = RKT_db::getInstance();
        $this->objfile = RKT_upload::getInstance(BLOB_DRIVER,BLOB_PARAM);

        $this->ref_message = empty($ref_message)?0:$ref_message;

        $objact = account::getInstance();
        $this->ref_account = $objact->getInfo('id');
        $this->set_ids();

        /* 削除画像IDの引継ぎ */
        if (!empty($_POST['picture_delete'])){
            $deletes = array();
            foreach ($_POST['picture_delete'] as $id) {
                if (is_numeric($id)){
                    $deletes[$id] = $id;
                }
            }
            $_SESSION['picture_delete'] = $deletes;
        } // if (!empty($_POST['picture_delete']))
    }

    /**
     * 添付ファイルIDの取得
     *
     * @access private
     * @return void
     */
    function set_ids()
    {
        if (isSet($_SESSION['ref_pictures'])){
            $this->ids = $_SESSION['ref_pictures'];
            return ;
        } // if (isSet($_SESSION['ref_pictures']))
        
        $sql=
            'SELECT '.
                'id '.
            'FROM '.
                DB_PREFIX.'fri_picture '.
            'WHERE '.
                'ref_account = '.$this->ref_account.' AND '.
                'ref_message = '.$this->ref_message;
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);

        $this->ids = array();
        if (empty($result)){
            return ;
        }
        foreach ($result as $value){
            $this->ids[$value['id']] = $value['id'];
        }
    }

    /**
     * 画像のアップロード処理
     *
     * @access public
     * @return integer  データ操作結果
     */
    function doUpload()
    {
        if (empty($_POST['ref_pictures'])){
            return ;
        }

        $this->ids = array();
        $row = 0;
        foreach ($_POST['ref_pictures'] as $id) {
            if (!empty($id)){
                $this->ids[$id] = is_numeric($id)?$id:0;
            }
            $this->upload($id, 'photo'.$row);
            $row++;
        }
        $_SESSION['ref_pictures'] = $this->ids;
    }

    /**
     * 画像のアップロード処理
     *
     * @access public
     * @return integer  データ操作結果
     */
    function upload($id, $name)
    {
        /* 一覧用画像 */
        if (!$this->objfile->catchFile($name)) {
            return false;
        }
        if (!$this->objfile->isImage()){
            return false;
        }

        // ファイルの保存
        $dir = ARCHIVES_UPLOAD_PATH;
        $filename = $this->objfile->getName();
        $extension = $this->objfile->getExtension();

        $temp = md5($this->ref_account.time());
        $name = substr($temp, rand(0,25), 6);

        $large_path = $dir.'large/'.$name.'.'.$extension;
        $small_path = $dir.'small/'.$name.'.'.$extension;

        $large = $this->objfile->saveResize($large_path,PHOTO_MAX_SIZE,PHOTO_MAX_SIZE);
        $small = $this->objfile->saveResize($small_path,PHOTO_SMALL_SIZE,PHOTO_SMALL_SIZE);

        /* テーブルの更新処理 */
        $objmnp = new RKT_manip($this->objdb, DB_PREFIX.'fri_picture');
        if (empty($id)){
            $objmnp->setValue('ref_account',    $this->ref_account);
        } else {
            $objmnp->setCurID($id);
            $this->file_unlink($id);
        }

        $objmnp->setValue('modify',         date('Y-m-d H:i:s'));
        $objmnp->setValue('title',          $filename);
        $objmnp->setValue('filename',       $large_path);
        $objmnp->setValue('width',          $large['width']);
        $objmnp->setValue('height',         $large['height']);
        $objmnp->setValue('thumbnail',      $small_path);
        $objmnp->setValue('t_width',        $small['width']);
        $objmnp->setValue('t_height',       $small['height']);

        $objmnp->manip();

        $id = $objmnp->getCurID();
        $this->ids[$id] = $id;

        return true;
    }

    /**
     * 添付画像の削除
     *
     * @access private
     * @param integer $id
     * @return boolean  真偽値
     */
    function file_unlink($id)
    {
        $sql=
            'SELECT '.
                'filename,'.
                'thumbnail '.
            'FROM '.
                DB_PREFIX.'fri_picture '.
            'WHERE '.
                'id = '.$id;
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetch(PDO_FETCH_ASSOC);
        $stmt->closeCursor();

        if (!empty($result)){
            $this->objfile->unlink($result['filename']);
            $this->objfile->unlink($result['thumbnail']);
        }

        return true;
    }

    /**
     * 画像の削除
     *
     * @access public
     * @param boolean $cahtch
     * @return integer  データ操作結果
     */
    function doDelete($catch=false)
    {
        if ($catch) {
            if (empty($_SESSION['picture_delete'])){
                return ;
            }
            $deletes = $_SESSION['picture_delete'];
            unset($_SESSION['picture_delete']);
        } // if ($catch)
        
        foreach ($deletes as $id){
            $this->delete($id);
        }
    }

    /**
     * 画像の削除
     *
     * @access public
     * @param integer $id
     * @return integer  データ操作結果
     */
    function delete($id)
    {
        $sql=
            'SELECT '.
                'filename,'.
                'thumbnail '.
            'FROM '.
                DB_PREFIX.'fri_picture '.
            'WHERE '.
                'id = '.$id;
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetch(PDO_FETCH_ASSOC);
        $stmt->closeCursor();

        if (empty($result)){
            return 0;
        }

        $this->objfile->unlink($result['filename']);
        $this->objfile->unlink($result['thumbnail']);

        $sql =
            'DELETE FROM '.
                DB_PREFIX.'fri_picture '.
            'WHERE '.
                'id = '.$id;
        return $this->objdb->exec($sql);
    }

    /**
     * 修正等を更新する
     *
     * @access public
     * @param integer $ref_message
     * @return boolean  真偽値
     */
    function setFix($ref_message)
    {
        foreach ($this->ids as $id){
            $this->fix($id,$ref_message);
        }
    }

    /**
     * 修正等を更新する
     *
     * @access public
     * @param integer $ref_message
     * @return boolean  真偽値
     */
    function fix($id,$ref_message)
    {
        $sql=
            'SELECT '.
                'filename,'.
                'thumbnail '.
            'FROM '.
                DB_PREFIX.'fri_picture '.
            'WHERE '.
                'id = '.$id;
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetch(PDO_FETCH_ASSOC);
        $stmt->closeCursor();

        if (empty($result)){
            return 0;
        }
        
        // ファイルの保存
        $dir = ARCHIVES_MEMBER_PATH.$this->ref_account.'/';

        $large_path = ereg_replace(ARCHIVES_UPLOAD_PATH, $dir, $result['filename']);
        $small_path = ereg_replace(ARCHIVES_UPLOAD_PATH, $dir, $result['thumbnail']);

        $this->objfile->setUID($this->ref_account);
        $this->objfile->rename($result['filename'], $large_path);
        $this->objfile->rename($result['thumbnail'], $small_path);
        
        $this->ref_message = $ref_message;
        $sql =
            'UPDATE '.
                DB_PREFIX.'fri_picture '.
            'SET '.
                "modify='".date('Y-m-d H:i:s')."',".
                'ref_message='.$this->ref_message.','.
                "filename='".$large_path."',".
                "thumbnail='".$small_path."' ".
            'WHERE '.
                'id = '.$id;
        return $this->objdb->exec($sql);
    }

    /**
     * 画像をコピーする
     *
     * @access public
     * @param integer $ref_message
     * @param integer $ref_to
     * @return boolean  真偽値
     */
    function setCopy($ref_message,$ref_to)
    {
        if (empty($ref_message)){
            return ;
        }
        foreach ($this->ids as $id){
            $this->copy($id,$ref_message,$ref_to);
        }
    }

    /**
     * 修正等を更新する
     *
     * @access public
     * @param integer $ref_message
     * @return boolean  真偽値
     */
    function copy($id,$ref_message,$ref_to)
    {
        $sql=
            'SELECT '.
                '* '.
            'FROM '.
                DB_PREFIX.'fri_picture '.
            'WHERE '.
                'id = '.$id;
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetch(PDO_FETCH_ASSOC);
        $stmt->closeCursor();

        if (empty($result)){
            return 0;
        }

        // ファイルの保存
        $dir = ARCHIVES_MEMBER_PATH.$ref_to.'/';

        $this->objfile->load($result['filename']);
        $basename = $this->objfile->getName();

        $large_path = $dir.'large/'.$basename;
        $small_path = $dir.'small/'.$basename;

        $this->objfile->setUID($ref_to);
        $this->objfile->save($large_path);

        $this->objfile->load($result['thumbnail']);        
        $this->objfile->setUID($ref_to);
        $this->objfile->save($small_path);

        /* テーブルの更新処理 */
        $objmnp = new RKT_manip($this->objdb, DB_PREFIX.'fri_picture');

        $objmnp->setValue('modify',         date('Y-m-d H:i:s'));
        $objmnp->setValue('ref_account',    $ref_to);
        $objmnp->setValue('ref_message',    $ref_message);
        $objmnp->setValue('title',          $result['title']);
        $objmnp->setValue('filename',       $large_path);
        $objmnp->setValue('width',          $result['width']);
        $objmnp->setValue('height',         $result['height']);
        $objmnp->setValue('thumbnail',      $small_path);
        $objmnp->setValue('t_width',        $result['t_width']);
        $objmnp->setValue('t_height',       $result['t_height']);

        return $objmnp->manip();
    }

    /**
     * 添付画像IDを削除
     *
     * @access public
     * @return void
     */
    function unSetPicture()
    {
        unset($_SESSION['ref_pictures']);
    }

    /**
     * 添付画像情報の取得
     *
     * @access public
     * @return array
     */
    function getImgInfos()
    {
        $ids = implode(',',$this->ids);

        $sql=
            'SELECT '.
                'id,'.
                'thumbnail as src,'.
                't_width as width,'.
                't_height as height '.
            'FROM '.
                DB_PREFIX.'fri_picture '.
            'WHERE '.
                'id in('.$ids.')';
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);

        $list = array();
        $row=0;
        foreach ($result as $value){
            $list[] = $value;
            $row++;
        }
        
        for ($row;$row<3;$row++) {
            $list[] = array(
                'id'=>       null,
                'src'=> NOPHOTO_SMALL,
                'width'=>  PHOTO_SMALL_SIZE,
                'height'=> PHOTO_SMALL_SIZE
            );
        }

        return $list;
    }
}
// msg_pictureの終了
?>
